@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: main.c,v 1.228 2003/05/15 20:20:52 miguelfreitas Exp $
+ * $Id: main.c,v 1.240 2003/07/22 21:33:08 f1rmb Exp $
  *
  * xine main for X11
  *
@@ -69,9 +69,7 @@
  * global variables
  */
 gGui_t                       *gGui;
-#ifdef HAVE_LIRC
-int                           no_lirc;
-#endif
+extern _panel_t              *panel;
 
 static char                 **video_driver_ids;
 static char                 **audio_driver_ids;
@@ -91,9 +89,15 @@ typedef struct {
 #define	OPTION_INSTALL_COLORMAP	1001
 #define DISPLAY_KEYMAP          1002
 #define OPTION_SK_SERVER        1003
-#define OPTION_ENQUEUE          2000
-#define OPTION_VERBOSE          3000
-#define OPTION_BROADCAST_PORT   4000
+#define OPTION_ENQUEUE          1004
+#define OPTION_VERBOSE          1005
+#define OPTION_BROADCAST_PORT   1006
+#define OPTION_NO_LOGO          1007
+#define OPTION_POST             1008
+#define OPTION_DISABLE_POST     1009
+#define OPTION_NO_SPLASH        1010
+#define OPTION_STDCTL           1011
+
 
 /* options args */
 static const char *short_options = "?hHgfvn"
@@ -106,7 +110,7 @@ static const char *short_options = "?hHgfvn"
 #ifdef HAVE_XF86VIDMODE
  "F"
 #endif
- "u:a:V:A:p::s:RG:BN:P:l::S:ZDr:c:";
+ "u:a:V:A:p::s:RG:BN:P:l::S:ZDr:c:E";
 
 static struct option long_options[] = {
   {"help"           , no_argument      , 0, 'h'                      },
@@ -143,10 +147,16 @@ static struct option long_options[] = {
   {"aspect-ratio"   , required_argument, 0, 'r'                      },
   {"config"         , required_argument, 0, 'c'                      },
   {"verbose"        , optional_argument, 0, OPTION_VERBOSE           },
+  {"stdctl"         , optional_argument, 0, OPTION_STDCTL            },
 #ifdef XINE_PARAM_BROADCASTER_PORT
   {"broadcast-port" , required_argument, 0, OPTION_BROADCAST_PORT    },
 #endif
-  {0                , no_argument      , 0,  0                       }
+  {"no-logo"        , no_argument      , 0, OPTION_NO_LOGO           },
+  {"no-reload"      , no_argument      , 0, 'E'                      },
+  {"post"           , required_argument, 0, OPTION_POST              },
+  {"disable-post"   , no_argument      , 0, OPTION_DISABLE_POST      },
+  {"no-splash"      , no_argument      , 0, OPTION_NO_SPLASH         },
+  {0                , no_argument      , 0, 0                        }
 };
 
 #undef TRACE_RC
@@ -316,7 +326,13 @@ static void xrm_parse(void) {
   XrmValue      value;
   
   XrmInitialize();
-  
+
+  rmdb = home_rmdb = server_rmdb = application_rmdb = NULL;
+  memset(&user_dbname, 0, sizeof(user_dbname));
+  memset(&environement_buf, 0, sizeof(environement_buf));
+  memset(&wide_dbname, 0, sizeof(wide_dbname));
+  memset(str_type, 0, sizeof(str_type));
+
   sprintf(wide_dbname, "%s%s", "/usr/lib/X11/app-defaults/", classname);
   
   if((display = XOpenDisplay((getenv("DISPLAY")))) == NULL)
@@ -378,9 +394,12 @@ static void main_change_logo_cb(void *data, xine_cfg_entry_t *cfg) {
  *
  */
 void show_version(void) {
-
-  printf(_("This is xine (X11 gui) - a free video player v%s\n"
-	   "(c) 2000-2003 by G. Bartsch and the xine project team.\n"), VERSION);
+  
+  printf(_("This is xine (X11 gui) - a free video player v%s"), VERSION);
+#ifdef DEBUG
+  printf("-[DEBUG]");
+#endif
+  printf(_(".\n(c) 2000-2003 The xine Team.\n"));
 }
 
 /*
@@ -519,6 +538,15 @@ void show_usage (void) {
   printf(_("      --broadcast-port <port>  Set port of xine broadcaster (master side)\n"));
   printf(_("                               Slave is started with 'xine slave://address:port'\n"));
 #endif
+  printf(_("      --no-logo                Don't display the logo.\n"));
+  printf(_("  -E, --no-reload              Don't reload old playlist.\n"));
+  printf(_("      --post <plugin>[:parameter=value][,...]\n"));
+  printf(_("                               Load a post plugin.\n"));
+  printf(_("                               Parameters are comma separated.\n"));
+  printf(_("                               This option can be used more than one time.\n"));
+  printf(_("      --disable-post           Don't enable post plugin(s).\n"));
+  printf(_("      --no-splash              Don't display the splash screen.\n"));
+  printf(_("      --stdctl                 Control xine by the console, using lirc commands.\n"));
   printf("\n");
   printf(_("examples for valid MRLs (media resource locator):\n"));
   printf(_("  File:  'path/foo.vob'\n"));
@@ -733,7 +761,13 @@ static xine_audio_port_t *load_audio_out_driver(int driver_number) {
 
     while (driver_ids[i]) {
       
-      printf (_("main: probing <%s> audio output plugin\n"), driver_ids[i]);
+      if( strcmp(driver_ids[i], "none") )
+        printf (_("main: probing <%s> audio output plugin\n"), driver_ids[i]);
+      else {
+        printf (_("main: skipping <%s> audio output plugin from auto-probe\n"), driver_ids[i]);
+        i++;
+        continue;
+      }
       
       audio_port = xine_open_audio_driver(gGui->xine, 
 					  driver_ids[i],
@@ -800,6 +834,17 @@ static void event_listener(void *user_data, const xine_event_t *event) {
   
   switch(event->type) { 
     
+  case XINE_EVENT_SPU_BUTTON:
+    {
+      xine_spu_button_t *spubtn = (xine_spu_button_t *) event->data;
+
+      if(spubtn->direction)
+	video_window_set_cursor(CURSOR_HAND);
+      else
+	video_window_set_cursor(CURSOR_ARROW);
+    }
+    break;
+
   /* frontend can e.g. move on to next playlist entry */
   case XINE_EVENT_UI_PLAYBACK_FINISHED:
     /*    printf("xitk/main.c: playback finished\n"
@@ -1001,8 +1046,10 @@ static void event_listener(void *user_data, const xine_event_t *event) {
     if(event->stream == gGui->stream) {
       xine_audio_level_data_t *aevent = (xine_audio_level_data_t *) event->data;
       
-      printf("XINE_EVENT_AUDIO_LEVEL: left 0>%d<255, right 0>%d<255\n", 
-	     aevent->left, aevent->right);
+      gGui->mixer.volume_level = (aevent->left + aevent->right) / 2;
+      gGui->mixer.mute = aevent->mute;
+      xitk_slider_set_pos(panel->mixer.slider, gGui->mixer.volume_level);
+      xitk_checkbox_set_state(panel->mixer.mute, gGui->mixer.mute);
     }
     break;
 
@@ -1077,6 +1124,9 @@ int main(int argc, char *argv[]) {
   int                     no_auto_start   = 0;
   char                   *cfgdir          = CONFIGDIR;
   char                   *cfgfile         = CONFIGFILE;
+  int                     old_playlist_cfg, no_old_playlist = 0;
+  char                  **pplugins        = NULL;
+  int                     pplugins_num    = 0;
 
 #ifdef HAVE_SETLOCALE
   if((xitk_set_locale()) != NULL)
@@ -1106,6 +1156,7 @@ int main(int argc, char *argv[]) {
   
   gGui->stream                 = NULL;
   gGui->debug_level            = 0;
+
   gGui->autoscan_plugin        = NULL;
   gGui->prefered_visual_class  = -1;
   gGui->prefered_visual_id     = None;
@@ -1122,6 +1173,14 @@ int main(int argc, char *argv[]) {
   gGui->skin_server_url        = NULL;
   gGui->verbosity              = 0;
   gGui->broadcast_port         = 0;
+  gGui->display_logo           = 1;
+  gGui->post_elements          = NULL;
+  gGui->post_elements_num      = 0;
+  gGui->post_enable            = 1;
+  gGui->splash                 = 1;
+#ifdef HAVE_LIRC
+  gGui->lirc_enable            = 1;
+#endif
 
   window_attribute.x     = window_attribute.y      = -8192;
   window_attribute.width = window_attribute.height = -1;
@@ -1132,14 +1191,6 @@ int main(int argc, char *argv[]) {
   _rc_file_check_args(_argc, _argv);
 #endif
 
-  /*
-   * initialize CORBA server
-   */
-#ifdef HAVE_ORBIT
-  if (!no_lirc)
-    xine_server_init (&_argc, _argv);
-#endif
-
   visual_anim_init();
 
   /*
@@ -1157,7 +1208,7 @@ int main(int argc, char *argv[]) {
 
 #ifdef HAVE_LIRC
     case 'L': /* Disable LIRC support */
-      no_lirc = 1;
+      gGui->lirc_enable = 0;
       break;
 #endif
 
@@ -1383,6 +1434,10 @@ int main(int argc, char *argv[]) {
       break;
 #endif
       
+    case OPTION_NO_LOGO:
+      gGui->display_logo = 0;
+      break;
+
     case 'S':
       session_handle_subopt(optarg, &session);
       break;
@@ -1402,6 +1457,29 @@ int main(int argc, char *argv[]) {
       }
       break;
 
+    case 'E':
+      no_old_playlist = 1;
+      break;
+
+    case OPTION_POST:
+      if(!pplugins_num)
+	pplugins = (char **) xine_xmalloc(sizeof(char *) * 2);
+      else
+	pplugins = (char **) realloc(pplugins, sizeof(char *) * (pplugins_num + 2));
+      
+      pplugins[pplugins_num] = optarg;
+      pplugins_num++;
+      pplugins[pplugins_num] = NULL;
+      break;
+
+    case OPTION_DISABLE_POST:
+      gGui->post_enable = 0;
+      break;
+
+    case OPTION_NO_SPLASH:
+      gGui->splash = 0;
+      break;
+
     case 'v': /* Display version and exit*/
       show_version();
       exit(1);
@@ -1413,6 +1491,10 @@ int main(int argc, char *argv[]) {
       exit(1);
       break;
 
+    case OPTION_STDCTL:
+      gGui->stdctl_enable = 1;
+      break;
+      
     default:
       show_usage();
       fprintf (stderr, _("invalid argument %d => exit\n"), c);
@@ -1492,6 +1574,26 @@ int main(int argc, char *argv[]) {
   gGui->xine = xine_new();
   xine_config_load(gGui->xine, gGui->configfile);
   xine_engine_set_param(gGui->xine, XINE_ENGINE_PARAM_VERBOSITY, gGui->verbosity);
+  
+  /* 
+   * Playlist auto reload 
+   */
+  old_playlist_cfg = 
+    xine_config_register_bool(gGui->xine, "gui.playlist_auto_reload", 
+			      0,
+			      _("Automatically reload old playlist"),
+			      _("If it's enabled and if you don't specify any MRL in command "
+				"line, xine will automatically load previous playlist."), 
+			      CONFIG_LEVEL_BEG,
+			      CONFIG_NO_CB,
+			      CONFIG_NO_DATA);
+
+  if(old_playlist_cfg && (!(_argc - optind)) && (!no_old_playlist)) {
+    char buffer[XITK_PATH_MAX + XITK_NAME_MAX + 1];
+    
+    sprintf(buffer, "%s/.xine/xine-ui_old_playlist.tox", xine_get_homedir());
+    mediamark_load_mediamarks(buffer);
+  }
 
   /*
    * init gui
@@ -1499,7 +1601,7 @@ int main(int argc, char *argv[]) {
   gui_init(_argc - optind, &_argv[optind], &window_attribute);
 
   pthread_mutex_init(&gGui->download_mutex, NULL);
-  
+
   /* Automatically start playback if new_mode is enabled and playlist is filled */
   if((gGui->smart_mode && 
       (gGui->playlist.num || actions_on_start(gGui->actions_on_start, ACTID_PLAYLIST)) &&
@@ -1510,6 +1612,17 @@ int main(int argc, char *argv[]) {
    * xine init
    */
   xine_init(gGui->xine);
+  
+  /* Get old working path from input plugin */
+  {
+    xine_cfg_entry_t  cfg_entry;
+    
+    if(xine_config_lookup_entry(gGui->xine, "input.file_origin_path", &cfg_entry))
+      sprintf(gGui->curdir, "%s", cfg_entry.str_value);
+    else
+      (void *) getcwd(&(gGui->curdir[0]), XITK_PATH_MAX);
+
+  }
 
   /*
    * load and init output drivers
@@ -1648,25 +1761,27 @@ int main(int argc, char *argv[]) {
 
   xine_set_param(gGui->stream, XINE_PARAM_VO_ASPECT_RATIO, aspect_ratio);
   
-  /*
-   * start CORBA server threadq
-   */
-#ifdef HAVE_ORBIT
-  if (!no_lirc)
-    xine_server_start (gGui->xine);
-#endif
-
   /*
    * hand control over to gui
    */
   gGui->actions_on_start[aos] = ACTID_NOKEY;
   
+  /* Initialize posts, if required */
+  if(pplugins_num) {
+    char             **plugin = pplugins;
+    
+    while(*plugin) {
+      pplugin_parse_and_store_post((const char *) *plugin);
+      *plugin++;
+    }
+    
+    pplugin_rewire_posts();
+  }
+  
   gui_run();
 
-#ifdef HAVE_ORBIT
-  if (!no_lirc)
-    xine_server_exit(gGui->xine);
-#endif
-
+  if(pplugins)
+    free(pplugins);
+  
   return 0;
 }
