@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: font.h,v 1.7 2003/01/05 00:24:35 f1rmb Exp $
+ * $Id: font.h,v 1.9 2003/07/18 21:34:40 f1rmb Exp $
  *
  */
 #ifndef HAVE_XITK_FONT_H
@@ -33,31 +33,33 @@
 #define DEFAULT_BOLD_FONT_14 "*-helvetica-bold-r-*-*-14-*-*-*-*-*-*-*"
 #define FONT_HEIGHT_MODEL    "azertyuiopqsdfghjklmwxcvbnAZERTYUIOPQSDFGHJKLMWXCVBN&(-_)=~#{[|`\\^@]}%"
 
+/*
+ * init font cache subsystem
+ */
+void xitk_font_cache_init(void);
+
+/*
+ * destroy font cache subsystem
+ */
+void xitk_font_cache_done(void);
+
 /*
  * load font from font name. Return NULL on failure.
  */
 xitk_font_t *xitk_font_load_font(Display *display, char *font);
 
+/*
+ * Draw the string with given font.
+ */
+void xitk_font_draw_string(xitk_font_t *xtfs, Pixmap pix, GC gc, 
+			   int x, int y, const char *text, 
+			   size_t nbytes);
+
 /*
  * Unload (free memory) font.
  */
 void xitk_font_unload_font(xitk_font_t *xtfs);
 
-/*
- * Return font ID (X).
- */
-Font xitk_font_get_font_id(xitk_font_t *xtfs);
-
-/*
- * Is font is 8 bits encoded.
- */
-int xitk_font_is_font_8(xitk_font_t *xtfs);
-
-/*
- * Is fon is 16 bits encoded.
- */
-int xitk_font_is_font_16(xitk_font_t *xtfs);
-
 /*
  * Return width (in pixel) of a string with length length.
  */
@@ -69,14 +71,16 @@ int xitk_font_get_text_width(xitk_font_t *xtfs, const char *c, int length);
 int xitk_font_get_string_length(xitk_font_t *xtfs, const char *c);
 
 /*
- * Return the char width (in pixel).
+ * Return the char width (in pixel),
+ * if nbytes != NULL returns there size of multibyte character in bytes.
  */
-int xitk_font_get_char_width(xitk_font_t *xtfs, unsigned char *c);
+int xitk_font_get_char_width(xitk_font_t *xtfs, char *c, int maxnbytes, int *nbytes);
 
 /*
  * Return the height (in pixel) of string, with length length.
+ * if nbytes != NULL returns there size of multibyte character in bytes.
  */
-int xitk_font_get_text_height(xitk_font_t *xtfs, const char *c, int length);
+int xitk_font_get_text_height(xitk_font_t *xtfs, const char *c, int nbytes);
 
 /*
  * Return string height (in pixel) of string.
@@ -86,7 +90,7 @@ int xitk_font_get_string_height(xitk_font_t *xtfs, const char *c);
 /*
  * Return char height (in pixel).
  */
-int xitk_font_get_char_height(xitk_font_t *xtfs, unsigned char *c);
+int xitk_font_get_char_height(xitk_font_t *xtfs, char *c, int maxnbytes, int *nbytes);
 
 /*
  * Get text extents of string length length.
