@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2002 the xine project
+ * Copyright (C) 2000-2003 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -17,33 +17,26 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: label.h,v 1.15 2002/07/17 20:29:31 f1rmb Exp $
+ * $Id: label.h,v 1.22 2003/07/14 22:44:10 f1rmb Exp $
  *
  */
 
 #ifndef HAVE_XITK_LABEL_H
 #define HAVE_XITK_LABEL_H
 
-#include <X11/Xlib.h>
-#include <pthread.h>
-
-#include "Imlib-light/Imlib.h"
-#include "widget.h"
 #include "_xitk.h"
 
 typedef struct {
   ImlibData              *imlibdata;
   char                   *skin_element_name;
-  GC                      gc;
-  Window                  window;
 
   xitk_widget_t          *lWidget;
 
-
   int                     char_length; /* length of 1 char */
   int                     char_height; /* height of 1 char */
 
-  Pixmap                  labelpix;
+  //  Pixmap                  labelpix;
+  xitk_pixmap_t          *labelpix;
 
   int                     length;      /* length in char */
   xitk_image_t           *font;
@@ -54,39 +47,17 @@ typedef struct {
   void                   *userdata;
 
   int                     animation;
+  int                     anim_step;
+  int                     anim_timer;
   int                     anim_running;
   int                     anim_offset;
 
   int                     on_change;
 
   pthread_t               thread;
+  pthread_mutex_t         paint_mutex;
 
 } label_private_data_t;
 
-/* ************************************************************** */
-
-/**
- * Create a label widget.
- */
-xitk_widget_t *xitk_label_create (xitk_widget_list_t *wl,
-				  xitk_skin_config_t *skonfig, xitk_label_widget_t *l);
-
-/*
- * Same as above, without skinable feature.
- */
-xitk_widget_t *xitk_noskin_label_create(xitk_widget_list_t *wl,
-					xitk_label_widget_t *l,
-					int x, int y, int width, int height, char *fontname);
-
-/**
- * Change label of widget 'widget'.
- */
-int xitk_label_change_label (xitk_widget_list_t *wl, xitk_widget_t *l, char *newlabel);
-
-/**
- *
- */
-char *xitk_label_get_label(xitk_widget_t *w);
-
 #endif
 
